# `pnextract` PyPI package

[![Build](https://github.com/lmmp-puc-rio/pnextract-pypi/actions/workflows/build.yml/badge.svg)](https://github.com/lmmp-puc-rio/pnextract-pypi/actions/workflows/build.yml)

This repository contains the source code for the `pnextract` PyPI package, which provides a convenient method for installing the [`pnextract`](https://github.com/ImperialCollegeLondon/pnextract) software.

## Installation

You can install `pnextract` using pip just as if it were a any Python package:

```bash
pip install pnextract
```
